import { Icon3D } from "@/assets/icons";
import { useEditor } from "@/modules/editor";
import { css } from "@linaria/core";
import { queenApi, useModal } from "queenjs";
import { defineComponent } from "vue";
import { string } from "vue-types";
import { useCompData } from ".";
import { View } from "../View";
import { IconClose } from "@queenjs/icons";

export const Component = defineComponent({
  props: {
    compId: string().isRequired,
  },
  setup(props) {
    const { store, controls } = useEditor();
    const { value } = useCompData(props.compId);

    async function pickPack() {
      await controls.pickCtrl.onPickPack();
      value.url =
        "https://www.sku3d.com/share.html?id=6478676ca494a3ea15a6fa82";
    }

    function openWeb3D() {
      queenApi.dialog(<Iframe3D url={value.url} />, { fullscreen: true, closable: false });
    }

    return () => {
      return (
        <View
          compId={props.compId}
          onDblclick={store.isEditMode ? pickPack : undefined}
        >
          <img
            class="w-full h-full object-cover pointer-events-none"
            style={{ aspectRatio: value.ratio }}
            src={value.poster}
          />
          <Icon3D
            class={iconCls}
            onClick={!store.isEditMode ? openWeb3D : undefined}
          />
        </View>
      );
    };
  },
});

const Iframe3D = defineComponent({
  props: {
    url: string().isRequired,
  },
  setup(props) {
    const modal = useModal();
    return () => (
      <div class="w-full h-full overflow-hidden relative">
        <IconClose class={closeCls} onClick={() => modal.cancel()} />
        <iframe class="w-full h-full border-none" src={props.url} />
      </div>
    );
  },
});

const iconCls = css`
  position: absolute;
  top: 50%;
  left: 50%;
  font-size: 1.5rem;
  color: #666;
  transform: translate(-50%, -50%);
  border-radius: 50%;
  background-color: rgba(255, 255, 255, 0.7);
`;

const closeCls = css`
  position: absolute;
  top: 0.3rem;
  left: 0.3rem;
  font-size: 0.3rem;
  color: #666;
  padding: 0.2rem;
  border-radius: 50%;
  background-color: #fff;
  @apply shadow;
`;
