import { DesignComp } from "@/modules/editor/objects/DesignTemp/DesignComp";
import { css } from "@linaria/core";
import { defineUI } from "queenjs";
import { onUnmounted, reactive } from "vue";
import { Container, Draggable } from "vue-dndrop";
import { useEditor } from "../../..";
import { HotKeyCtrl } from "../../../controllers/HotKeyCtrl";
import { CompUI } from "../../CompUI";
import { Transfer } from "../../CompUI/basicUI/Transfer";

export default defineUI({
  setup() {
    const editor = useEditor();
    const { store, actions, helper, controls } = editor;

    const hotKeyCtrl = new HotKeyCtrl(editor);
    hotKeyCtrl.init();
    onUnmounted(() => {
      hotKeyCtrl.destroy();
    });

    const state = reactive({
      draging: false,
    });

    const NotFoundComp = () => <div>无效的组件</div>;

    return () => {
      const pageRoot = helper.findRootComp();
      if (!pageRoot) return;
      return (
        <div class="flex justify-center my-60px ">
          <CompUI.Page.Component class={contentStyle} compId={pageRoot.id}>
            {{
              Container(children: any) {
                return (
                  <>
                    <Container
                      class={store.isEditPage ? "!min-h-750px" : ""}
                      group-name="canvas"
                      onDrop={(e: any) => {
                        if (e.payload) {
                          actions.addCompToDesign(e.payload, e.addedIndex);
                        } else {
                          actions.moveComp(e.removedIndex, e.addedIndex);
                        }
                      }}
                      onDragStart={() => (state.draging = true)}
                      onDragEnd={() => (state.draging = false)}
                      non-drag-area-selector={".drag-disable"}
                    >
                      {children}
                    </Container>
                    {store.currCompId &&
                      store.currCompId !== "root" &&
                      !store.textEditingState &&
                      !state.draging && <Transfer key={store.currCompId} />}
                  </>
                );
              },
              CompItem(comp: DesignComp) {
                const Comp =
                  controls.compUICtrl.state.components.get(comp.compKey)
                    ?.Component || NotFoundComp;
                return (
                  <Draggable class="!flex flex-col" key={comp.id}>
                    <Comp compId={comp.id} />
                  </Draggable>
                );
              },
            }}
          </CompUI.Page.Component>
        </div>
      );
    };
  },
});

const contentStyle = css`
  width: 375px;
  position: relative;
  user-select: none;

  .dndrop-container.vertical > .dndrop-draggable-wrapper {
    overflow: unset;
  }
`;
