import { EditorModule } from "@/modules/editor/module";
import { ResourceModule } from "@/modules/resource";
import { PromotionController } from "@/modules/resource/controllers/PromotionController";
import { PageListController } from "@queenjs/controllers";
import ShareModal from "./components/ShareModal";

export function createPromotinController(
  resource: ResourceModule,
  editor: EditorModule
) {
  const ctrl = new PromotionController();

  ctrl.ListCtrl = new PageListController(resource.config?.httpConfig);
  ctrl.ListCtrl.setCrudPrefix("/h5");
  ctrl.createPromotion = resource.actions.createPromotion;

  function updateDesign(record: any, data: any) {
    for (const [key, value] of Object.entries(data)) {
      record[key] = value;
    }

    const designData: any = Object.assign({}, { _id: record._id }, data);
    editor.https.saveDesign(designData);
  }

  async function sharePromotion(record: any) {
    editor.actions.initDesign(record._id);
    editor.actions.switchMode("preview");
    resource.showModal(
      <ShareModal
        record={record}
        onEdit={() => ctrl.onEdit(record)}
        onUpdate={(data) => updateDesign(record, data)}
        onChangeThumnb={async () => {
          const { file } = await resource.helper.uploadResource();
          updateDesign(record, { thumbnail: file.url });
        }}
      >
        {{
          preview: () => <editor.components.Preview />,
        }}
      </ShareModal>,
      {
        title: "编辑分享",
        width: "1000px",
      }
    );
  }

  ctrl.onMenuClick = async (name, record) => {
    switch (name) {
      case "delete":
        await resource.actions.deletePromotion(record);
        ctrl.ListCtrl.fresh();
        break;
      case "rename":
        await resource.actions.renamePromotion(record);
        break;
      case "share":
        sharePromotion(record);
        break;
    }
  };

  return ctrl;
}
